==> doccheck_basic-8.x-1.0.tar.gz: doccheck_basic/src/doccheckBasicCommon.php <==
<?php

namespace Drupal\doccheck_basic;
/**
 * @file
 * Contains \Drupal\doccheck_basic\doccheckBasicCommon
 */

class doccheckBasicCommon {
    const template_size=[
        's_red' => ['w'=>156, 'h'=>203],
        'm_red' => ['w'=>311, 'h'=>188],
        'l_red' => ['w'=>424, 'h'=>215],
        'xl_red' => ['w'=>467, 'h'=>231],
    ];

    /**
    * {@inheritdoc}
    */
    static function doccheck_basic_login(){
        \Drupal::service('page_cache_kill_switch')->trigger();
        $config = \Drupal::config('config.doccheck_basic');
        if (strlen($config->get('dc_loginid')) < 1){
            $err_msg=t('DocCheck Login ID not set');
            \Drupal::logger('doccheck_basic')->error($err_msg);
            drupal_set_message($err_msg, 'error');
            return [
                '#markup' => '',
                '#cache' => [
                    'max-age' => 0,
                ],
            ];
        }

        if (\Drupal::currentUser()->isAnonymous()) {
            \Drupal::request()->getSession()->set('forced', TRUE);
        }
        \Drupal::request()->getSession()->set('dc_page',
            \Drupal::request()->getRequestUri());


        return [
            '#theme' => 'doccheck_basic',
            '#dctemplate' => $config->get('dc_template'),
            '#width' => self::template_size[$config->get('dc_template')]['w'],
            '#height' => self::template_size[$config->get('dc_template')]['h'],
            '#language' => \Drupal::languageManager()->getCurrentLanguage()->getId(),
            '#loginid' => $config->get('dc_loginid'),
            '#devmode' => ($config->get('dc_devmode')) ?
                ('<a href="' . \Drupal::request()->getSchemeAndHttpHost() . '/_dc_callback">' . t('Development mode login') . '</a>') :
                (''),
            '#cache' => [
                'max-age' => 0,
            ],
        ];
    }
}

==> doccheck_basic-8.x-1.1.tar.gz: doccheck_basic/src/doccheckBasicCommon.php <==
<?php

namespace Drupal\doccheck_basic;
/**
 * @file
 * Contains \Drupal\doccheck_basic\doccheckBasicCommon
 */

class doccheckBasicCommon {
    /**
    * Defines doccheck login for block and page
    */
    static function doccheck_basic_login(){
        \Drupal::service('page_cache_kill_switch')->trigger();
        $config = \Drupal::config('config.doccheck_basic');
        if (strlen($config->get('dc_loginid')) < 1){
            $err_msg=t('DocCheck Login ID not set');
            \Drupal::logger('doccheck_basic')->error($err_msg);
            drupal_set_message($err_msg, 'error');
            return [
                '#markup' => '',
                '#cache' => [
                    'max-age' => 0,
                ],
            ];
        }

        if (\Drupal::currentUser()->isAnonymous()) {
            \Drupal::request()->getSession()->set('forced', TRUE);
        }
        \Drupal::request()->getSession()->set('dc_page',
            \Drupal::request()->getRequestUri());


        return [
            '#theme' => 'doccheck_basic',
            '#dctemplate' => $config->get('dc_template'),
            '#width' => self::template_size($config->get('dc_template'), 'w'),
            '#height' => self::template_size($config->get('dc_template'), 'h'),
            '#language' => \Drupal::languageManager()->getCurrentLanguage()->getId(),
            '#loginid' => $config->get('dc_loginid'),
            '#devmode' => ($config->get('dc_devmode')) ?
                ('<a href="' . \Drupal::request()->getSchemeAndHttpHost() . '/_dc_callback">' . t('Development mode login') . '</a>') :
                (''),
            '#cache' => [
                'max-age' => 0,
            ],
        ];
    }

    /**
    * Returns width or height of doccheck template
    */
    static function template_size($type, $dimension){
        $template_size=[
            's_red' => ['w'=>156, 'h'=>203],
            'm_red' => ['w'=>311, 'h'=>188],
            'l_red' => ['w'=>424, 'h'=>215],
            'xl_red' => ['w'=>467, 'h'=>231],
        ];
        return (isset($template_size[$type]))?($template_size[$type][$dimension]):(false);
    }
}
